eprllib.Utils.Utils — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Utils.Utils

## General utilities

Work in progress…

Functions

`building_dimension`(epJSON_object, h, w, l, ...) | _summary_
`calcular_centro`(ventana) |
`effective_thermal_capacity`(epJSON_object) | The effective_thermal_capacity function calculates the total effective thermal capacity of a building based on the construction materials and surface areas specified in an EnergyPlus JSON object.
`fenestration_area`(epJSON_object, fenestration) | _summary_
`find_dict_key_by_nested_key`(key, lists_dict) | _summary_
`generate_occupancy_schedule`(input_path, ...) | Generates an updated occupancy schedule based on typical residential patterns.
`generate_variated_schedule`(input_path, ...) | Generates a new CSV with variations in schedule data.
`generate_variated_schedule_with_shift`(...[, ...]) | Generates a new CSV with variations and optional time shift in schedule data.
`inertial_mass_calculation`(env_config) | The function reads the epjson file path from the env_config dictionary.
`material_area`(epJSON_object, nombre_superficie) | _summary_
`random_building_config`(env_config) | This method define the path to the epJSON file.
`u_factor`(epJSON_object) | This function select all the building surfaces and fenestration surfaces and calculate the global U-factor of the building, like EnergyPlus does.
`u_factor_calculation`(env_config) | The u_factor_calculation function calculates the U-factor (a measure of heat transfer through a building element) based on the provided environment configuration (env_config).
`variable_checking`(epJSON_file) | This function check if the epJSON file has the required variables.
`window_size_epJSON`(epJSON_object, window, ...) | Given a epJSON_object, return another epJSON_object with diferent size of windows.